@@ -73,6 +73,16 @@ func TestGuessRepoURL(t *testing.T) {
 			expectedHTTPRepoURL: "https://github.com/user/dotfiles.git",
 			expectedSSHRepoURL:  "git@github.com:user/dotfiles.git",
 		},
+		{
+			arg:                 "user/chezmoi_dotfiles",
+			expectedHTTPRepoURL: "https://github.com/user/chezmoi_dotfiles.git",
+			expectedSSHRepoURL:  "git@github.com:user/chezmoi_dotfiles.git",
+		},
+		{
+			arg:                 "user/.dotfiles",
+			expectedHTTPRepoURL: "https://github.com/user/.dotfiles.git",
+			expectedSSHRepoURL:  "git@github.com:user/.dotfiles.git",
+		},
 		{
 			arg:                 "user/dots",
 			expectedHTTPRepoURL: "https://github.com/user/dots.git",
